@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package namespace::autoclean;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # ABSTRACT: Keep imports out of your namespace
 
@@ -13,15 +13,17 @@ use namespace::clean;
 
 sub import {
     my ($class, %args) = @_;
-    my $caller = caller();
+
+    my $cleanee = exists $args{-cleanee} ? $args{-cleanee} : scalar caller;
+
     my @also = exists $args{-also}
         ? (ref $args{-also} eq 'ARRAY' ? @{ $args{-also} } : $args{-also})
         : ();
     on_scope_end {
-        my $meta = Class::MOP::class_of($caller) || Class::MOP::Class->initialize($caller);
+        my $meta = Class::MOP::class_of($cleanee) || Class::MOP::Class->initialize($cleanee);
         my %methods = map { ($_ => 1) } keys %{$meta->get_method_map};
         my @symbols = keys %{ $meta->get_all_package_symbols('CODE') };
-        namespace::clean->clean_subroutines($caller, @also, grep { !$methods{$_} } @symbols);
+        namespace::clean->clean_subroutines($cleanee, @also, grep { !$methods{$_} } @symbols);
     };
 }
 
@@ -34,7 +36,7 @@ namespace::autoclean - Keep imports out of your namespace
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -74,6 +76,20 @@ accepts a plain string:
 
     use namespace::autoclean -also => 'some_function';
 
+If you're writing an exporter and you want to clean up after yourself (and your
+peers), you can use the C<-cleanee> switch to specify what package to clean:
+
+  package My::MooseX::namespace::autoclean;
+  use strict;
+
+  use namespace::autocleanclean (); # no cleanup, just load
+
+  sub import {
+      namespace::autoclean->import(
+        -cleanee => scalar(caller),
+      );
+  }
+
 =head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
